@@ -12,7 +12,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkPanedWindow.c,v 1.13.2.4 2003/08/19 21:00:13 jenglish Exp $
+ * RCS: @(#) $Id: tkPanedWindow.c,v 1.13.2.5 2004/05/03 19:17:39 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -1748,6 +1748,18 @@ Unlink(slavePtr)
 	}
     }
 
+    /*
+     * Clean out any -after or -before references to this slave
+     */
+    for (i = 0; i < masterPtr->numSlaves; i++) {
+	if (masterPtr->slaves[i]->before == slavePtr->tkwin) {
+	    masterPtr->slaves[i]->before = None;
+	}
+	if (masterPtr->slaves[i]->after == slavePtr->tkwin) {
+	    masterPtr->slaves[i]->after = None;
+	}
+    }
+
     masterPtr->flags |= REQUESTED_RELAYOUT;
     if (!(masterPtr->flags & REDRAW_PENDING)) {
 	masterPtr->flags |= REDRAW_PENDING;
